==> cr12g-panhuo-api-3.0.0-20210521.095122-59-sources.jar: com/ejianc/business/panhuo/vo/AllotVO.java <==
package com.ejianc.business.panhuo.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 调拨单
 *
 * @author generator
 *
 */
public class AllotVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Integer belongType; // 调出类型 0=项目，1=公司
    private java.lang.Integer assetBelongType; // 资产归属 0-项目，1-公司
    private java.lang.Long belongOrgId; // 归属公司主键
    private java.lang.String belongOrgName; // 归属公司名称
    private java.lang.String assetCode; // 资产编码
    private java.lang.Long assetId; // 物资主键
    private java.lang.Long goodsId; // 资产主键
    private java.lang.Long orderId; // 订单主键
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialName; // 物资名称
    private java.lang.String billCode;
    private java.lang.String materialCode; // 物资编号
    private java.lang.Long materialTypeId; // 物资类别
    private java.lang.String materialTypeCode; // 物资类别编号
    private java.lang.String materialTypeName; // 物资类别名称
    private java.lang.Integer assetType; // 物资类型 0-周转材，1-台车
    private java.lang.String assetTypeName; // 物资类型 0-周转材，1-台车
    private java.math.BigDecimal capacity; // 承载量
    private java.lang.String sourceId; // 物资来源ID
    private java.lang.Long systemId; // 所属系统ID
    private java.lang.String spec; // 规格型号
    private java.lang.String mainimgPath; // 资产主图URL
    private java.lang.String unit; // 单位
    private java.math.BigDecimal price; // 成交单价
    private java.math.BigDecimal nums; // 成交数量
    private java.math.BigDecimal amount; // 成交金额
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private java.util.Date dealrTime; // 成交时间
    private java.lang.Long confirmer; // 调出负责人
    private java.lang.String confirmerName; // 调出负责人名称
    private java.lang.Long sellOrg; // 调出组织主键
    private java.lang.String sellOrgName; // 调出组织名称
    private java.lang.Long sellProject; // 调出项目
    private java.lang.String sellProjectName; // 调出项目名称
    private java.lang.Long orderUserId; // 调入负责人
    private java.lang.String orderUserName; // 调入负责人名称
    private java.lang.Long buyOrg; // 调入组织主键
    private java.lang.String buyOrgName; // 调入组织名称
    private java.lang.Long buyProject; // 调入项目主键
    private java.lang.String buyProjectName; // 调入项目名称
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态（审批必须字段）wei
    private java.lang.Integer state; //状态 0-未被引用 1-被引用

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getAssetTypeName() {
        return assetTypeName;
    }

    public void setAssetTypeName(String assetTypeName) {
        this.assetTypeName = assetTypeName;
    }

    /**
     * 资产主键
     */
    public java.lang.Long getGoodsId() {
        return goodsId;
    }

    /**
     * 资产主键
     */
    public void setGoodsId(java.lang.Long goodsId) {
        this.goodsId = goodsId;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public Integer getBelongType() {
        return belongType;
    }

    public void setBelongType(Integer belongType) {
        this.belongType = belongType;
    }

    public Integer getAssetBelongType() {
        return assetBelongType;
    }

    public void setAssetBelongType(Integer assetBelongType) {
        this.assetBelongType = assetBelongType;
    }

    public Long getBelongOrgId() {
        return belongOrgId;
    }

    public void setBelongOrgId(Long belongOrgId) {
        this.belongOrgId = belongOrgId;
    }

    public String getBelongOrgName() {
        return belongOrgName;
    }

    public void setBelongOrgName(String belongOrgName) {
        this.belongOrgName = belongOrgName;
    }

    public String getAssetCode() {
        return assetCode;
    }

    public void setAssetCode(String assetCode) {
        this.assetCode = assetCode;
    }

    public Long getAssetId() {
        return assetId;
    }

    public void setAssetId(Long assetId) {
        this.assetId = assetId;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public Integer getAssetType() {
        return assetType;
    }

    public void setAssetType(Integer assetType) {
        this.assetType = assetType;
    }

    public BigDecimal getCapacity() {
        return capacity;
    }

    public void setCapacity(BigDecimal capacity) {
        this.capacity = capacity;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    /**
     * 订单主键
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资编号
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物资编号
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别末级
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别末级
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别末级名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别末级名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资来源ID
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 物资来源ID
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 所属系统ID
     */
    public java.lang.Long getSystemId() {
        return systemId;
    }

    /**
     * 所属系统ID
     */
    public void setSystemId(java.lang.Long systemId) {
        this.systemId = systemId;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 资产主图URL
     */
    public java.lang.String getMainimgPath() {
        return mainimgPath;
    }

    /**
     * 资产主图URL
     */
    public void setMainimgPath(java.lang.String mainimgPath) {
        this.mainimgPath = mainimgPath;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 成交单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 成交单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 成交数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 成交数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 成交金额
     */
    public java.math.BigDecimal getAmount() {
        return amount;
    }

    /**
     * 成交金额
     */
    public void setAmount(java.math.BigDecimal amount) {
        this.amount = amount;
    }
    /**
     * 成交时间
     */
    public java.util.Date getDealrTime() {
        return dealrTime;
    }

    /**
     * 成交时间
     */
    public void setDealrTime(java.util.Date dealrTime) {
        this.dealrTime = dealrTime;
    }
    /**
     * 调出负责人
     */
    public java.lang.Long getConfirmer() {
        return confirmer;
    }

    /**
     * 调出负责人
     */
    public void setConfirmer(java.lang.Long confirmer) {
        this.confirmer = confirmer;
    }
    /**
     * 调出负责人名称
     */
    public java.lang.String getConfirmerName() {
        return confirmerName;
    }

    /**
     * 调出负责人名称
     */
    public void setConfirmerName(java.lang.String confirmerName) {
        this.confirmerName = confirmerName;
    }
    /**
     * 调出组织主键
     */
    public java.lang.Long getSellOrg() {
        return sellOrg;
    }

    /**
     * 调出组织主键
     */
    public void setSellOrg(java.lang.Long sellOrg) {
        this.sellOrg = sellOrg;
    }
    /**
     * 调出组织名称
     */
    public java.lang.String getSellOrgName() {
        return sellOrgName;
    }

    /**
     * 调出组织名称
     */
    public void setSellOrgName(java.lang.String sellOrgName) {
        this.sellOrgName = sellOrgName;
    }
    /**
     * 调出项目
     */
    public java.lang.Long getSellProject() {
        return sellProject;
    }

    /**
     * 调出项目
     */
    public void setSellProject(java.lang.Long sellProject) {
        this.sellProject = sellProject;
    }
    /**
     * 调出项目名称
     */
    public java.lang.String getSellProjectName() {
        return sellProjectName;
    }

    /**
     * 调出项目名称
     */
    public void setSellProjectName(java.lang.String sellProjectName) {
        this.sellProjectName = sellProjectName;
    }
    /**
     * 调入负责人
     */
    public java.lang.Long getOrderUserId() {
        return orderUserId;
    }

    /**
     * 调入负责人
     */
    public void setOrderUserId(java.lang.Long orderUserId) {
        this.orderUserId = orderUserId;
    }
    /**
     * 调入负责人名称
     */
    public java.lang.String getOrderUserName() {
        return orderUserName;
    }

    /**
     * 调入负责人名称
     */
    public void setOrderUserName(java.lang.String orderUserName) {
        this.orderUserName = orderUserName;
    }
    /**
     * 调入组织主键
     */
    public java.lang.Long getBuyOrg() {
        return buyOrg;
    }

    /**
     * 调入组织主键
     */
    public void setBuyOrg(java.lang.Long buyOrg) {
        this.buyOrg = buyOrg;
    }
    /**
     * 调入组织名称
     */
    public java.lang.String getBuyOrgName() {
        return buyOrgName;
    }

    /**
     * 调入组织名称
     */
    public void setBuyOrgName(java.lang.String buyOrgName) {
        this.buyOrgName = buyOrgName;
    }
    /**
     * 调入项目主键
     */
    public java.lang.Long getBuyProject() {
        return buyProject;
    }

    /**
     * 调入项目主键
     */
    public void setBuyProject(java.lang.Long buyProject) {
        this.buyProject = buyProject;
    }
    /**
     * 调入项目名称
     */
    public java.lang.String getBuyProjectName() {
        return buyProjectName;
    }

    /**
     * 调入项目名称
     */
    public void setBuyProjectName(java.lang.String buyProjectName) {
        this.buyProjectName = buyProjectName;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }

}

==> cr12g-panhuo-api-3.0.0-20210804.174050-125-sources.jar: com/ejianc/business/panhuo/vo/AllotVO.java <==
package com.ejianc.business.panhuo.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 调拨单
 *
 * @author generator
 *
 */
public class AllotVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Integer belongType; // 调出类型 0=项目，1=公司
    private java.lang.Integer assetBelongType; // 资产归属 0-项目，1-公司
    private java.lang.Long belongOrgId; // 归属公司主键
    private java.lang.String belongOrgName; // 归属公司名称
    private java.lang.String assetCode; // 资产编码
    private java.lang.Long assetId; // 物资主键
    private java.lang.Long goodsId; // 资产主键
    private java.lang.Long orderId; // 订单主键
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialName; // 物资名称
    private java.lang.String billCode;
    private java.lang.String materialCode; // 物资编号
    private java.lang.Long materialTypeId; // 物资类别
    private java.lang.String materialTypeCode; // 物资类别编号
    private java.lang.String materialTypeName; // 物资类别名称
    private java.lang.Integer assetType; // 物资类型 0-周转材，1-台车
    private java.lang.String assetTypeName; // 物资类型 0-周转材，1-台车
    private java.math.BigDecimal capacity; // 承载量
    private java.lang.String sourceId; // 物资来源ID
    private java.lang.Long systemId; // 所属系统ID
    private java.lang.String spec; // 规格型号
    private java.lang.String mainimgPath; // 资产主图URL
    private java.lang.String unit; // 单位
    private java.math.BigDecimal price; // 成交单价
    private java.math.BigDecimal nums; // 成交数量
    private java.math.BigDecimal amount; // 成交金额
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private java.util.Date dealrTime; // 成交时间
    private java.lang.Long confirmer; // 调出负责人
    private java.lang.String confirmerName; // 调出负责人名称
    private java.lang.Long sellOrg; // 调出组织主键
    private java.lang.String sellOrgName; // 调出组织名称
    private java.lang.Long sellProject; // 调出项目
    private java.lang.String sellProjectName; // 调出项目名称
    private java.lang.Long orderUserId; // 调入负责人
    private java.lang.String orderUserName; // 调入负责人名称
    private java.lang.Long buyOrg; // 调入组织主键
    private java.lang.String buyOrgName; // 调入组织名称
    private java.lang.Long buyProject; // 调入项目主键
    private java.lang.String buyProjectName; // 调入项目名称
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态（审批必须字段）wei
    private java.lang.Integer state; //状态 0-未被引用 1-被引用
    private java.lang.Integer orderType; // 订单类型 0-调拨下单，1-租赁下单

    private java.lang.String orderTypeName;

    public String getOrderTypeName() {
        return this.orderType == null ? null : this.orderType == 0 ? "调拨" : "租赁";
    }

    public void setOrderTypeName(String orderTypeName) {
        this.orderTypeName = orderTypeName;
    }

    public Integer getOrderType() {
        return orderType;
    }

    public void setOrderType(Integer orderType) {
        this.orderType = orderType;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getAssetTypeName() {
        return assetTypeName;
    }

    public void setAssetTypeName(String assetTypeName) {
        this.assetTypeName = assetTypeName;
    }

    /**
     * 资产主键
     */
    public java.lang.Long getGoodsId() {
        return goodsId;
    }

    /**
     * 资产主键
     */
    public void setGoodsId(java.lang.Long goodsId) {
        this.goodsId = goodsId;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public Integer getBelongType() {
        return belongType;
    }

    public void setBelongType(Integer belongType) {
        this.belongType = belongType;
    }

    public Integer getAssetBelongType() {
        return assetBelongType;
    }

    public void setAssetBelongType(Integer assetBelongType) {
        this.assetBelongType = assetBelongType;
    }

    public Long getBelongOrgId() {
        return belongOrgId;
    }

    public void setBelongOrgId(Long belongOrgId) {
        this.belongOrgId = belongOrgId;
    }

    public String getBelongOrgName() {
        return belongOrgName;
    }

    public void setBelongOrgName(String belongOrgName) {
        this.belongOrgName = belongOrgName;
    }

    public String getAssetCode() {
        return assetCode;
    }

    public void setAssetCode(String assetCode) {
        this.assetCode = assetCode;
    }

    public Long getAssetId() {
        return assetId;
    }

    public void setAssetId(Long assetId) {
        this.assetId = assetId;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public Integer getAssetType() {
        return assetType;
    }

    public void setAssetType(Integer assetType) {
        this.assetType = assetType;
    }

    public BigDecimal getCapacity() {
        return capacity;
    }

    public void setCapacity(BigDecimal capacity) {
        this.capacity = capacity;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    /**
     * 订单主键
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资编号
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物资编号
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别末级
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别末级
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别末级名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别末级名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资来源ID
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 物资来源ID
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 所属系统ID
     */
    public java.lang.Long getSystemId() {
        return systemId;
    }

    /**
     * 所属系统ID
     */
    public void setSystemId(java.lang.Long systemId) {
        this.systemId = systemId;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 资产主图URL
     */
    public java.lang.String getMainimgPath() {
        return mainimgPath;
    }

    /**
     * 资产主图URL
     */
    public void setMainimgPath(java.lang.String mainimgPath) {
        this.mainimgPath = mainimgPath;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 成交单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 成交单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 成交数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 成交数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 成交金额
     */
    public java.math.BigDecimal getAmount() {
        return amount;
    }

    /**
     * 成交金额
     */
    public void setAmount(java.math.BigDecimal amount) {
        this.amount = amount;
    }
    /**
     * 成交时间
     */
    public java.util.Date getDealrTime() {
        return dealrTime;
    }

    /**
     * 成交时间
     */
    public void setDealrTime(java.util.Date dealrTime) {
        this.dealrTime = dealrTime;
    }
    /**
     * 调出负责人
     */
    public java.lang.Long getConfirmer() {
        return confirmer;
    }

    /**
     * 调出负责人
     */
    public void setConfirmer(java.lang.Long confirmer) {
        this.confirmer = confirmer;
    }
    /**
     * 调出负责人名称
     */
    public java.lang.String getConfirmerName() {
        return confirmerName;
    }

    /**
     * 调出负责人名称
     */
    public void setConfirmerName(java.lang.String confirmerName) {
        this.confirmerName = confirmerName;
    }
    /**
     * 调出组织主键
     */
    public java.lang.Long getSellOrg() {
        return sellOrg;
    }

    /**
     * 调出组织主键
     */
    public void setSellOrg(java.lang.Long sellOrg) {
        this.sellOrg = sellOrg;
    }
    /**
     * 调出组织名称
     */
    public java.lang.String getSellOrgName() {
        return sellOrgName;
    }

    /**
     * 调出组织名称
     */
    public void setSellOrgName(java.lang.String sellOrgName) {
        this.sellOrgName = sellOrgName;
    }
    /**
     * 调出项目
     */
    public java.lang.Long getSellProject() {
        return sellProject;
    }

    /**
     * 调出项目
     */
    public void setSellProject(java.lang.Long sellProject) {
        this.sellProject = sellProject;
    }
    /**
     * 调出项目名称
     */
    public java.lang.String getSellProjectName() {
        return sellProjectName;
    }

    /**
     * 调出项目名称
     */
    public void setSellProjectName(java.lang.String sellProjectName) {
        this.sellProjectName = sellProjectName;
    }
    /**
     * 调入负责人
     */
    public java.lang.Long getOrderUserId() {
        return orderUserId;
    }

    /**
     * 调入负责人
     */
    public void setOrderUserId(java.lang.Long orderUserId) {
        this.orderUserId = orderUserId;
    }
    /**
     * 调入负责人名称
     */
    public java.lang.String getOrderUserName() {
        return orderUserName;
    }

    /**
     * 调入负责人名称
     */
    public void setOrderUserName(java.lang.String orderUserName) {
        this.orderUserName = orderUserName;
    }
    /**
     * 调入组织主键
     */
    public java.lang.Long getBuyOrg() {
        return buyOrg;
    }

    /**
     * 调入组织主键
     */
    public void setBuyOrg(java.lang.Long buyOrg) {
        this.buyOrg = buyOrg;
    }
    /**
     * 调入组织名称
     */
    public java.lang.String getBuyOrgName() {
        return buyOrgName;
    }

    /**
     * 调入组织名称
     */
    public void setBuyOrgName(java.lang.String buyOrgName) {
        this.buyOrgName = buyOrgName;
    }
    /**
     * 调入项目主键
     */
    public java.lang.Long getBuyProject() {
        return buyProject;
    }

    /**
     * 调入项目主键
     */
    public void setBuyProject(java.lang.Long buyProject) {
        this.buyProject = buyProject;
    }
    /**
     * 调入项目名称
     */
    public java.lang.String getBuyProjectName() {
        return buyProjectName;
    }

    /**
     * 调入项目名称
     */
    public void setBuyProjectName(java.lang.String buyProjectName) {
        this.buyProjectName = buyProjectName;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }

}
